@@ -60,6 +60,8 @@ static int pp_undef(char*);
 #define   VALBEF    6
 
 static int ungeteof = 0;
+static int quotebs = 0;
+static int inquote = 0;
 
 static char *cmd[]={ "echo","include","define","undef","printdef","print",
 			"ifdef","ifndef","else","endif",
@@ -792,7 +794,7 @@ int pp_open(char *name)
      flist[0].filep=fp;
      flist[0].flinep=NULL;    
 
-     return(((long)fp)==0l);
+     return (fp == NULL);
 }
 
 void pp_close(void)
@@ -875,6 +877,7 @@ int pgetline(char *t)
      int c,er=E_OK;
      int rlen, tlen;
      char *p = 0;
+     char *q = 0;
 
      loopfl =0; /* set if additional fetch needed */
 
@@ -924,12 +927,38 @@ int pgetline(char *t)
 	}
 
      /* handle the double-slash comment (like in C++) */
-     p = strchr(in_line, '/');
-     if (p != NULL) {
-	if (p[1] == '/') {
-	    *p = 0;	/* terminate string */
+	/* get p past any quoted strings */
+	p = strchr(in_line, '/');
+	if (p != NULL) {
+		q = strchr(in_line, '"');
+		for(;;) {
+			/* no more quotes to skip, or slashes before quotes */
+			if (q == NULL || (p < q)) {
+				if (p[1] == '/') {
+					/* truncate line, done with loop */
+					*p = 0;
+					break;
+				} else {
+					/* wasn't //, but could be later */
+					p++;
+				}
+			} else {
+				/* quote before slash, so skip string */
+				q++;
+				while (*q != 0 && *q != '"') {
+					if (*q == '\\') q++;
+					if (*q != 0) q++;
+				}
+				if (*q == 0) break; /* oops */
+				q++;
+				p = q;
+			}
+
+			p = strchr(p, '/');
+			if (p == NULL) break; /* never mind */
+			if (q != NULL) q = strchr(q, '"');
+		}
 	}
-     }
 
      if(!er || loopfl) {
           in_line[0]='\0';
@@ -987,15 +1016,22 @@ int egetc(FILE *fp) {
 /* smart getc that can skip C comment blocks */
 int rgetc(FILE *fp)
 {
-     static int c,d,fl;
-
+     static int c,cc,d,fl;
+     cc=0;
      fl=0;
 
      do
      {
           while((c=egetc(fp))==13);  /* remove ^M for unices */
 
-          if(fl && (c=='*'))
+          /* flag if we're in a quoted string */
+          if(c=='"' && !quotebs) inquote ^= 1;
+#if(0)
+/* implement backslashed quotes for 2.4 */
+          if(c=='\\') quotebs=1; else quotebs=0;
+#endif
+
+          if(!inquote && fl && (c=='*'))
           {
                if((d=egetc(fp))!='/')
                     ungetc(d,fp);
@@ -1005,12 +1041,14 @@ int rgetc(FILE *fp)
                     while((c=egetc(fp))==13);
                }
           }
+
+          /* in comment block */
           if(c=='\n')
           {
                flist[fsp].fline++;
                nlf=1;
           } else
-          if(c=='/')
+          if(!inquote && c=='/')
           {
                if((d=egetc(fp))!='*')
                     ungetc(d,fp);
